@@ -1,4 +1,5 @@
-from lexsub import EmbeddingLookup, LexSubExample
+from lexsub.algorithms.embedding_utils import EmbeddingLookup
+from lexsub.process_data.definition import LexSubExample
 
 
 class DataReader:
